#!/usr/bin/env python
'''
tbb is cantankerous package to build.  This feature should follow
"tarball" or another that provides the "unpacked" step.

This file is forked from worch/examples/tbbinst.py.
'''
from waflib.TaskGen import feature
import orch.features

def configure(cfg):
    orch.features.register_defaults(
        'tbbinst',
        # gratuitious wart _src
        source_archive_file = '{source_unpacked}_src.tgz',
        unpacked_target = 'Makefile',
        # Non standard location to build - must match source unpacked
        build_target = 'crappy-build-system',
        install_target = 'lib/libtbb.so',
    )
    return

def build(bld):
    pass

@feature('tbbinst')
def feature_tbbinst(tgen):

    flag = tgen.make_node(tgen.worch.build_dir).make_node(tgen.worch.build_target)
    build_rule = "(cd src && make cpp0x=1 tbb_release) && touch %s"
    tgen.step('build',
              rule = build_rule % flag.abspath(),
              source = tgen.control_node('unpack'),
              target = flag)

    instdir = tgen.make_node(tgen.worch.install_dir)
    #libdir = tgen.make_node(instdir.abspath() + '/lib')
    instarg = instdir.make_node(tgen.worch.install_target)
    libpath = instarg.parent.abspath()
    #instarg = instdir.find_or_declare(tgen.worch.install_target)
    print 'INSTDIR:', instdir.abspath()
    #print 'LIBDIR:',libdir.abspath()
    print 'INSTARG:', instarg.abspath()
    #libdir = instarg.parent.abspath()
    install_rule = 'mkdir -p %s && cp build/*_release/libtbb* %s/ && cp -a include %s'
    install_rule = install_rule % (libpath, libpath, instdir.abspath())
    tgen.step('install',
              rule = install_rule,
              source = flag,
              target = instarg)




#!/usr/bin/env python
'''A "tarball"-like feature to which pulls from a VCS instead.  It
provides the "seturl" and "unpack" steps.  There is no "download" step
like "tarball" as the checkout/clone is direct to the source
directory.

'''
import os.path as osp
from waflib.TaskGen import feature
import waflib.Logs as msg

from orch.wafutil import exec_command

import orch.features
orch.features.register_defaults(
    'pandorasrc', 
    source_urlfile = '{urlfile_dir}/{package}-{version}.url',
    source_unpacked = '{package}-{version}',
    source_unpacked_path = '{source_dir}/{source_unpacked}',
    unpacked_target = 'Makefile',
    source_unpacked_target = '{source_unpacked_path}/{unpacked_target}',

    vcs_flavor = 'svn',         # git,hg,svn,cvs 
    vcs_tag = 'v00-17',
    vcs_module = '',            # used by cvs
)

def single_cmd_rule(func):
    def rule(tgen):
        def task_func(task):
            cmd = func(tgen)
            return exec_command(task, cmd)
        tgen.step('unpack',
                  rule = task_func,
                  source = tgen.worch.source_urlfile,
                  target = tgen.worch.source_unpacked_target)
    return rule


@single_cmd_rule
def do_svn(tgen):
    tag = tgen.worch.get('vcs_tag', '')
    pat = "svn --non-interactive --trust-server-cert checkout {source_url}/PandoraPFANew/tags/{vcs_tag_opt} {source_unpacked};svn --non-interactive --trust-server-cert checkout {source_url}/PandoraSDK/tags/{vcs_tag_opt} {source_unpacked}/PandoraSDK;svn --non-interactive --trust-server-cert checkout {source_url}/PandoraMonitoring/tags/{vcs_tag_opt} {source_unpacked}/PandoraMonitoring"
    return tgen.worch.format(pat, vcs_tag_opt = tag)


@feature('pandorasrc')
def feature_pandorasrc(tgen):

    tgen.step('seturl', 
              rule = "echo '%s' > %s" % (tgen.worch.source_url, tgen.worch.source_urlfile),
              update_outputs = True,
              target = tgen.worch.source_urlfile)

    flavor = tgen.worch.vcs_flavor
    doer = eval('do_%s' % flavor)
    doer(tgen)
    return
    
    



from glob import glob
from setuptools import setup, find_packages

# def git(cmd):
#     import subprocess    
#     out = subprocess.check_output("git %s"%cmd, shell=True)
#     return out.strip()

# def current_version():
#     branch = [x[2:] for x in git("branch").split('\n') if x.startswith('* ')][0]
#     if branch.startswith("release/"):
#         return open("RELEASE-VERSION").read().strip()
#     return git("describe --dirty")

setup(name = 'lbne-build',
      version = '0.5.0',
      description = 'Worch/waf tools to build LBNE software.',
      author = 'Brett Viren',
      author_email = 'brett.viren@gmail.com',
      license = 'GPLv2',
      url = 'http://github.com/LBNE/lbne-build',
      namespace_packages = ['worch'],
      packages = ['worch','worch.lbne','worch.lbne.tbbinst','worch.lbne.pandorasrc'],
      install_requires = [l for l in open("requirements.txt").readlines() if l.strip()],
      data_files = [
          ('share/worch/config/lbne', glob('config/*.cfg')),
          ('share/worch/patches/lbne', glob('patches/lbne/*.patch')),
          ('share/worch/wscripts/lbne', ['wscript']),
      ],
)
